%Funkcja "WGM" - laboriatorium PTS
%Autor: Jakub Zmigrodzki
%Instytut Metrologi i Inzynirii Biomedycznej Politechniki Warszawskiej
%Warszawa, 2008

% funkcja "WGM" wyznacza widmowa gestosc mocy sygnalu wejsiowego
%parametrami wyjciowymi sa:
% f - wektor czstotliwosc dla ktorych zostaly wyliczone wartosci widma
% amplitudowego
% WGM - wektor wartosci widmowej gestosci mocy

function [f, WGM] = WGM(syg, nfft, fp, okno, beta ,typ_wykresu) 

% parametrami wejsciowymi sa:
% syg - sygnal wejsciowy
% nfft - dlugosc DFT
% fp - czestotliwosc probkowania sygnalu syg,
% okno - typ zastosowanj funkcji granic,
% beta - parametr dla okna kaisera,
% typ_wykresu - wybor pomiedzy wykresem liniowym, logarytmicznym, a brakiem wykresu,

if isempty(nfft)
    nfft=length(syg);
end;

if isempty(beta)
    beta=0.5;
end;

if isempty(okno)
    okno='prostokatne';
end;

if isempty(typ_wykresu)
    typ_wykresu='';
end;

switch lower(okno)
    case 'prostokatne'
        wind=rectwin(length(syg));
    case 'hann'
        wind=hann(length(syg));
    case 'hamming'
        wind=hamming(length(syg));
    case 'blackman'
        wind=blackman(length(syg));
    case 'kaiser'
        wind=kaiser(length(syg),beta);
    otherwise
        wind=[];
end;

[WGM,f]=periodogram(syg,wind,nfft,fp);


switch lower(typ_wykresu)
    case 'liniowy'
        figure
        plot(f,WGM,'k');
        grid on;
        xlabel('f[Hz]');
        ylabel('WGM[1/Hz]');

    case 'logarytmiczny'
        figure
        WGMdB=10.*log10(WGM./max(WGM));
        plot(f,WGMdB,'k');
        grid on;
        xlabel('f[Hz]');
        ylabel('WGM[dB]');
        axis([0,fp/2,-100,0]);
    otherwise
        disp('bez rysunku')
end;