%Funkcja "sygnal" - laboriatorium PTS
%Autor: Jakub Zmigrodzki
%Instytut Metrologi i Inzynirii Biomedycznej Politechniki Warszawskiej
%Warszawa, 2008

% funkcja "sygnal" generuje sygnal sinusoidalny, prostokatny, trojkatny
% badz losowy (szum biay gaussowski)  
%parametrami wyjciowymi sa:
% syg - wektor wartosci
% t - wektor czasu

function [t, syg] = sygnal (typ, Amp, fsyg, faza, sk_stala, wsp_wyp, fp, T, typ_wykresu)

% paramety wejsciowe:
% typ - typ sygnalu jaki ma zostac wygenerowany:
%     - 'sinus'
%     - 'prostokat'
%     - 'trojkat'
%     - 'losowy'
% Amp - amplituda generowanego sygnalu
% fsyg - czestotliwosc geneowanego sygnalu
% faza - faza geneowanego sygnalu
% sk_stala - skladowa stala geneowanego sygnalu
% wsp_wyp - wspolczynnik wypelnienia geneowanego sygnalu,
% fp - czestotliwosc probkowania geneowanego sygnalu
% T - czas trwania (probkowania) geneowanego sygnalu
% typ wykresu - wykres dyskretny, ciagy lub brak wykresu


% ustawienie parametrow domyslnych
if isempty(wsp_wyp)
    wsp_wyp=50;
end;

if isempty(Amp)
    Amp=1;
end;

if isempty(faza)
    faza=0;
end;

if isempty(sk_stala)
    sk_stala=0;
end;

if isempty(typ_wykresu)
    typ_wykresu='';
end;

%wyzanczenie ilosci probek sygnalu
n=round(T*fp);   
%utworzenie wektora czasu
t=(0:n-1)./fp; 

% generacja odpowiedniego typu sygnalu
switch lower(typ)
    case 'sinus'
        syg=Amp*sin(2*pi*fsyg*t+faza)+sk_stala;
    case 'prostokat'
        syg=Amp*square(2*pi*fsyg*t+faza,wsp_wyp)+sk_stala;
    case 'trojkat'
        syg=Amp*sawtooth(2*pi*fsyg*t+faza,wsp_wyp/100)+sk_stala;
    case 'losowy'
        randn('state', sum(100*clock));
        syg=Amp*randn(1,n)+sk_stala;
    otherwise
        disp('Nieznany typ')
end;

%prezentacja graficzna

switch lower(typ_wykresu)
    case 'dyskretny'
        figure
        stem(t,syg,'k');
        grid on;
        xlabel('t[s]');
        ylabel('x(t)');

    case 'ciagly'
        figure
        plot(t,syg,'k');
        grid on;
        xlabel('t[s]');
        ylabel('x(t)');

    otherwise
        disp('bez rysunku')
end;